SLOTS = [
    [
        0,
        5460,
        ["172.17.0.2", 7000, "cf0da23bbea0ac65fd93d272358b59cd7ce3af25"],
        ["172.17.0.2", 7003, "ab35b1210fcae1010a463c65e1616b51d3d7a00b"],
    ],
    [
        9995,
        9995,
        ["172.17.0.2", 7000, "cf0da23bbea0ac65fd93d272358b59cd7ce3af25"],
        ["172.17.0.2", 7003, "ab35b1210fcae1010a463c65e1616b51d3d7a00b"],
    ],
    [
        12182,
        12182,
        ["172.17.0.2", 7000, "cf0da23bbea0ac65fd93d272358b59cd7ce3af25"],
        ["172.17.0.2", 7003, "ab35b1210fcae1010a463c65e1616b51d3d7a00b"],
    ],
    [
        5461,
        9994,
        ["172.17.0.2", 7001, "d0299b606a9f2634ddbfc321e4164c1fc1601dc4"],
        ["172.17.0.2", 7004, "8e691f344dbf1b398792a7bca48ec7f012a2cc35"],
    ],
    [
        9996,
        10922,
        ["172.17.0.2", 7001, "d0299b606a9f2634ddbfc321e4164c1fc1601dc4"],
        ["172.17.0.2", 7004, "8e691f344dbf1b398792a7bca48ec7f012a2cc35"],
    ],
    [10923, 12181, ["172.17.0.2", 7002, "c80666a77621a0061a3af77a1fda46c94c2abcb9"]],
    [12183, 16383, ["172.17.0.2", 7002, "c80666a77621a0061a3af77a1fda46c94c2abcb9"]],
]


INFO = """
cluster_state:ok
cluster_current_epoch:1
cluster_slots_assigned:16384
cluster_slots_ok:16384
cluster_slots_pfail:0
cluster_slots_fail:0
cluster_known_nodes:6
cluster_size:3
cluster_current_epoch:1
cluster_my_epoch:1
"""
